# cca_FFNet_pca.praat
# djmw 20010131
# djmw 20050225 Latest revision

savedir$ = "/home/david/tex/thesis/cca/"
include /home/david/tex/praat_procedures.praat

# neural net stuf

nhidden = 2
dir$ = savedir$
name$ = "cca_FFNet_pca"
ffnetfile$ = dir$ +"cca_autoassocFFNet_2.FFNet"

Read from file... 'ffnetfile$'
Rename... t

Create TableOfReal (Pols 1973)... n
Rename... t
Formula... if col < 4 then log10(self/((2*col-1)*500)) + 0.5 else self fi

ncols = Get number of columns
nrows = Get number of rows
Split into Pattern and Categories... 0 0 0 0

select FFNet t
plus Pattern t
To Activation... 1
Rename... t
plus Categories t
To TableOfReal
Rename... hidden
Set column label (index)... 1 node1
Set column label (index)... 2 node2

select FFNet t
plus Pattern t
plus Activation t
plus Categories t
Remove

# pca stuf

select TableOfReal t
To PCA
vaf = Get fraction variance accounted for... 1 2
printline Fraction vaf = 'vaf'
plus TableOfReal t
To Configuration... 2
To TableOfReal
Rename... pca

select PCA t
plus Configuration untitled
Remove

select TableOfReal hidden
plus TableOfReal pca
Append columns
Rename... hidden-pca
To CCA... 2

call vp_init 12 6 2 1 1
call vp_next
Draw eigenvector... y 1 no 0 0 -1 1 1 + yes yes
Dotted line
Draw eigenvector... y 2 no 0 0 -1 1 1 o yes no
Plain line

call vp_next
Draw eigenvector... x 1 no 0 0 -1 1 1 + yes yes
Dotted line
Draw eigenvector... x 2 no 0 0 -1 1 1 o yes yes
Plain line

call save cca-ffnet-hidden-eigenvectors

# prepare table with cc and eigenvectors for latex output

Create TableOfReal... cca 2 5
Set column label (index)... 1 $\rho$
for i to 2
  select CCA hidden-pca
  rho = Get correlation... i
  select TableOfReal cca
  Set value... i 1 rho
  Set column label (index)... 1+i node'i'
  Set column label (index)... 3+i pc'i'
  Set row label (index)... i 'i'

  for j to 2
    select CCA hidden-pca
    ccy = Get eigenvector element... y i j 
    ccx = Get eigenvector element... x i j
    select TableOfReal cca
    Set value... i j+1 ccy
    Set value... i j+3 ccx
  endfor
endfor

call latex_table cca 3


pause draw hidden and pc1-2 scatter plots

select TableOfReal hidden

call vp_init 12 6 2 1 1
call vp_next
Draw scatter plot... 1 2 0 0 0.35 0.65 0.35 0.65 10 y + y
One mark bottom... 0.45 n y n
One mark bottom... 0.55 n y n
One mark left... 0.45 n y n
One mark left... 0.55 n y n
s = 0.25
sx = 0.65 - 0.35
sy = 0.65 - 0.35
x0 = 0.65 - sx * s
y0 = 0.65 - sy * s
for i to 2
  x = TableOfReal_cca[i, 2]
  y = TableOfReal_cca[i, 3]
  Plain line
  if i = 2 
    Dotted line
  endif
  Draw arrow... x0 y0 x0+x*s*sx y0+y*s*sx 
endfor


call vp_next

select TableOfReal pca
Draw scatter plot... 1 2 0 0 -0.2 0.5 -1.1 -0.3 10 y + y
Marks bottom every... 1 0.1 n y n
Marks left every... 1 0.1 n y n
s = 0.25
sx = 0.5 - (-0.2)
sy = abs(-0.3 - (-1.1))
x0 = 0.5 - sx * s
y0 = -1.1 + sy * s
for i to 2
  x = TableOfReal_cca[i, 4]
  y = TableOfReal_cca[i, 5]
  Plain line
  if i = 2 
    Dotted line
  endif
  Draw arrow... x0 y0 x0+x*s*sx y0+y*s*sx 
endfor

call save cca-ffnet-hidden-pca

# Now try Procrustes
#  transform hidden to pc

select TableOfReal hidden
plus TableOfReal pca
To Configuration
To Procrustes... n
Rename... h_p
Invert

r = Get transformation element... 1 1
angle = arccos(r) * 180/ pi
printline rotation angle='angle' degrees
plus Configuration hidden
To Configuration
Rename... hiddenp
To TableOfReal
Set column label (index)... 1 node1\'p
Set column label (index)... 2 node2\'p


# get correlations between nodes and pc's
# upper triangle: node & pc's
# lower triangle: prorustus(nodes) & pc's

select TableOfReal hidden-pca
To Correlation
Rename... correlation
To TableOfReal

select TableOfReal pca
Copy... pcac
plus TableOfReal hiddenp
Append columns
Rename... hiddenp_pca
To Correlation
Rename... tmp

select TableOfReal correlation
Formula... if row > col then Correlation_tmp[row,col] else self fi
Set row label (index)... 1 node1\'p
Set row label (index)... 2 node2\'p

execute /home/david/tex/printTableOfReal_latex.praat correlation 3

# project data with CCA (->scores)

select TableOfReal hidden-pca
plus CCA hidden-pca
To TableOfReal (scores)... 2
Set column label (index)... 1 %y_1
Set column label (index)... 2 %y_2

Set column label (index)... 1 %x_1
Set column label (index)... 2 %x_2

pause draw hidden-pca-scores

call vp_init 12 6 2 1 1
call vp_next

Draw scatter plot... 1 2 0 0 0.0 0.4 0.5 0.8 10 y + y
Marks bottom every... 1 0.1 n y n
Marks left every... 1 0.1 n y n
call vp_next

Draw scatter plot... 3 4 0 0 -0.2 0.5 0.3 1.1 10 y + y
Marks bottom every... 1 0.1 n y n
Marks left every... 1 0.1 n y n

call save cca-hidden-pca-scores

pause procrustes transformed hidden vs pc

call vp_init 12 6 2 1 1
call vp_next
select TableOfReal hiddenp
Draw scatter plot... 1 2 0 0 -0.2 0.5 -1.1 -0.3 10 y + y
Marks bottom every... 1 0.1 n y n
Marks left every... 1 0.1 n y n
call vp_next
select TableOfReal pca
Draw scatter plot... 1 2 0 0 -0.2  0.5 -1.1 -0.3 10 y + y
Marks bottom every... 1 0.1 n y n
Marks left every... 1 0.1 n y n

call save cca-hidden-pca-procrustes




