# cca_plots.praat
# djmw 20031219
# djmw 20060821 Latest revision

savedir$ = "/home/david/tex/thesis/cca/"
include /home/david/tex/praat_procedures.praat

Create TableOfReal (Pols 1973)... yes
Copy... lin
Copy... lins
Standardize columns

select TableOfReal pols_50males
Formula... if col<4 then log10(self) else self fi
for i to 3
  Set column label (index)... 'i' log %F_'i'
  Set column label (index)... i+3 %L_'i'
endfor
Rename... log
Copy... logs
Standardize columns

call vp_init 10 10 1 1 1
call vp_next
Draw scatter plot... 1 2 0 0 -3 3 -3 3 12 y + y
One mark bottom... 0 y n n
One mark left... 0 y n n
call save cca-logf1-vs-logf2

pause CCA eigenvectors
call vp_init 12 6 2 1 1
call vp_next

select TableOfReal logs
To CCA... 3
cc1 = Get correlation... 1

Draw eigenvector... y 1 no 0 0 -1 1 1 + yes yes
Dotted line
Draw eigenvector... y 2 no 0 0 -1 1 1 + yes no
Plain line
One mark bottom... 2 n y n log %F_2

call vp_next
Draw eigenvector... x 1 no 0 0 -1 1 1 + yes yes
Dotted line
Draw eigenvector... x 2 no 0 0 -1 1 1 + yes no
Plain line
One mark bottom... 2 n y n %L_2

call save cca-eigenvectors

select TableOfReal lin
plus TableOfReal lins
plus TableOfReal log
plus TableOfReal logs
To Correlation

select Correlation logs
Confidence intervals... 0.95 0 Ruben
Rename... logs_confidence

pause Correlation coefficients

call vp_init 14 15 1 4 1
call vp_next


procedure draw_correlation cor$
  select Correlation 'cor$'
  Draw as numbers... 1 0 decimal 3
  call vp_next
endproc

call draw_correlation lin
call draw_correlation lins
call draw_correlation log
call draw_correlation logs

# some in latex form

Create TableOfReal... vecs 3 7
Set column label (index)... 1 $\rho$
for i to 3
  Set column label (index)... i+1 $\log F_'i'$
  k = 1 + 3 + i
  Set column label (index)... k $L_'i'$
  Set row label (index)... i 'i'
endfor

for i to 3
  select CCA logs
  c0 = Get correlation... i
  for j to 3
    c'j' = Get eigenvector element... y i j
    k = 3 + j
    c'k' = Get eigenvector element... x i j 
  endfor
  select TableOfReal vecs
  for j from 1 to 7
    k = j - 1
    Set value... i j c'k'
  endfor   
endfor

# combine two correlations into one TabelOfReal

procedure set_log_L_labels table$
  select TableOfReal 'table$'
  for i to 3
    Set column label (index)... i $\log F_'i'$
    Set row label (index)... i $\log F_'i'$
    k = 3 + i
    Set column label (index)... k $L_'i'$
    Set row label (index)... k $L_'i'$
  endfor
endproc

Create TableOfReal... cors 6 6
Formula... if col < row then Correlation_logs[row,col] else Correlation_lins[row,col] fi
call set_log_L_labels cors

printline 'newline$'Correlations: 'newline$'
# change log labels on columns
for i to 3
  Set column label (index)... i F_'i'
endfor
execute /home/david/tex/printTableOfReal_latex.praat cors 3

printline 'newline$'Correlations confidence intervals: 'newline$'
call set_log_L_labels logs_confidence
execute /home/david/tex/printTableOfReal_latex.praat logs_confidence 3

printline 'newline$'CCA eigenvectors: 'newline$'
call latex_table vecs 3


# prediction

select TableOfReal logs
plus CCA logs
Predict... 4
Rename... logsp

select TableOfReal logs
Extract column ranges... 1 2 3
Rename... f123
To Discriminant
plus TableOfReal f123
To ClassificationTable... y y
Rename... f123
To Confusion
fc1 = Get fraction correct

select Discriminant f123
plus TableOfReal logsp
To ClassificationTable... y y
Rename... f123_logsp
To Confusion
fc2 = Get fraction correct

printline Classification: 'fc1', prediction: 'fc2'


# draw first cononical variates
pause Draw canonical variates y1 vs x1
call vp_init 10 10 1 1 1
call vp_next

select TableOfReal logs
plus CCA logs
To TableOfReal (scores)... 1
Set column label (index)... 1 %y_1
Set column label (index)... 2 %x_1
Draw scatter plot... 2 1 0 0 -3.1 3.1 -3.1 3.1 12 y + y
One mark bottom... 0 y n n
One mark left... 0 y n n
Line width... 2
Draw line... -3 -3*cc1 3 3*cc1
Line width... 1 

call save cca-y1-vs-x1

pause Draw FFNet

call vp_init 7 7 1 1 1
call vp_next

Create FFNet... 3-2-3 3 3 2 0
Draw topology
x1 = 1/6
y1 = 0
y2 = 1
for i to 3 
  Text special... x1 Centre y1 Half Helvetica 10 0 %f_'i'
  Text special... x1 Centre y2 Half Helvetica 10 0 %f_'i'
  x1 += 1/3
endfor

call save cca-ffnet-topology

pause Draw box plots

call vp_init 12 6 2 1 1
call vp_next

Create TableOfReal (Pols 1973)... no
Rename... l
for i to 3
  Set column label (index)... i log %F_'i'
endfor

Formula... log10(self)
Draw box plots... 0 0 0 0 2 4 yes

call vp_next
Create TableOfReal (Pols 1973)... no
Rename... ls
for i to 3
  Set column label (index)... i %f_'i'
endfor
Formula... log10(self/((2*col-1)*500))+0.5
Draw box plots... 0 0 0 0 0 1 yes

call save cca-f13-boxplots

procedure remove
  select TableOfReal lins
  plus TableOfReal lin
  plus TableOfReal log
  plus TableOfReal logs
  plus TableOfReal logs_scores
  plus TableOfReal logsp
  plus TableOfReal l
  plus TableOfReal ls
  plus Correlation logs
  plus Correlation log
  plus Correlation lins
  plus Correlation lin
  plus CCA logs
  plus TableOfReal f123
  plus Discriminant f123
  plus ClassificationTable f123
  plus Confusion f123
  plus ClassificationTable f123_logsp
  plus Confusion f123_logsp
  plus FFNet 3-2-3
  Remove
endproc

call remove
