# bias-adaptation-test.praat
# djmw 20040427
# djmw 20040604 added form + different input set
# djmw 20041104 make adaptation of hidden layer possible
# djmw 20041115 Adapt both layers (one output table)
# djmw 20041125 Reorder final table

form Bias-adaptation-test
  comment Select from 630 speakers for training
  comment 438 (326+112) males, 192 (136+56) females
  comment indices m(1, 327), f(439,575)
  natural Speaker_train1 1
  natural Speaker_train2 10
  natural Speaker_test1 1
  natural Speaker_test2 630
  natural Sequence_number 1
endform


number_of_iterations_train = 1000
number_of_iterations_test = 100
number_of_repetitions = 10


date$ = "20041125_'sequence_number'"
home$ = "/home/david/"
datadir$ = home$+"tex/thesis/nn-bias2/"
savedir$ = home$+"tex/thesis/nn-bias2/"

name$ = "barks_total_frame2_mf"

# Read 9 dimensional table

#Read from file... 'datadir$''name$'_pd9.TableOfReal
Read from file... 'datadir$''name$'_sep_pc9.TableOfReal
table_total = selected ("TableOfReal")
Centre columns
Formula... (self+80)/160

# Read speaker indices

Read from file... 'savedir$''name$'_index.TableOfReal
speakerindex = selected ("TableOfReal")
nspeakers = Get number of rows

# Check given speaker indices

if speaker_train1 > speaker_train2 or speaker_train2 > nspeakers
  exit Speaker_train1 and Speaker_train2 should be in [1, 'nspeakers']
endif
if speaker_test1 > speaker_test2 or speaker_test2 > nspeakers 
  exit Speaker_test1 and Speaker_test2 should be in [1, 'nspeakers']
endif

row_train1 = Get value... speaker_train1 1
row_train2 =  Get value... speaker_train2 2
nitems_train = row_train2 - row_train1 + 1
nspeakers_train = speaker_train2 - speaker_train1 + 1
printline row_train1 = 'row_train1', row_train2 = 'row_train2', 
  ... nitems_train = 'nitems_train', nspeakers_train = 'nspeakers_train'

row_test1 = Get value... speaker_test1 1
row_test2 =  Get value... speaker_test2 2
nitems_test = row_test2 - row_test1 + 1
nspeakers_test = speaker_test2 - speaker_test1 + 1
printline row_test1 = 'row_test1', row_test2 = 'row_test2', 
  ... nitems_test = 'nitems_test', nspeakers_test = 'nspeakers_test'

#pause

# split off the items from the selected speakers to train the neural net

select table_total
ncols = Get number of columns
To Pattern and Categories... row_train1 row_train2 0 0
pattern_train = selected ("Pattern")
categories_train = selected ("Categories")

static_columns = 5
ncols_result =  static_columns + 3 * 4 * number_of_repetitions
Create TableOfReal... result nspeakers_test ncols_result
result = selected ("TableOfReal")
offset = 1
Set column label (index)... offset Begin
offset += 1
Set column label (index)... offset End
offset += 1
Set column label (index)... offset Speaker
offset += 1
Set column label (index)... offset Iter\\_ train
offset += 1
Set column label (index)... offset Iter\\_ test
offset += 1

for i to number_of_repetitions

  Set column label (index)... offset Eb-'i'
  offset += 1
  Set column label (index)... offset Cb-'i'
  offset += 1
  Set column label (index)... offset Ea-'i'
  offset += 1
  Set column label (index)... offset Ca-'i'
  offset += 1
  
  for layer to 2
    Set column label (index)... offset Ebh'layer'-'i'
    offset += 1
    Set column label (index)... offset Cbh'layer'-'i'
    offset += 1
    Set column label (index)... offset Eah'layer'-'i'
    offset += 1
    Set column label (index)... offset Cah'layer'-'i'
    offset += 1
  endfor
endfor

# global-vars: global_fractionCorrect, global_cost
procedure get_fractioncorrect ffnet_id pattern_id categories_id
  select ffnet_id
  plus pattern_id
  To Categories... Winner-takes-all
  categories_2tmp = selected ("Categories")
  plus categories_id
  f_tmp = Get fraction different
  fractionCorrect = 1 - f_tmp
  select categories_2tmp
  Remove
endproc

procedure get_costs ffnet_id pattern_id categories_id
  select ffnet_id
  plus pattern_id
  plus categories_id
  costs = Get average costs... Minimum-squared-error
endproc

procedure save_results ffnet_id pattern_id categories_id table_id row
  call get_costs ffnet_id pattern_id categories_id
  call get_fractioncorrect ffnet_id pattern_id categories_id
  select table_id
  Set value... row global_column costs
  global_column += 1
  Set value... row global_column fractionCorrect
  global_column += 1 
endproc

for i to number_of_repetitions

  select pattern_train
  plus categories_train
  To FFNet... 9 0
  ffnet = selected ("FFNet")

  call get_fractioncorrect ffnet pattern_train categories_train
  fractionCorrect_pre = fractionCorrect
  call get_costs ffnet pattern_train categories_train
  costs_pre = costs
  
  select ffnet
  plus pattern_train
  plus categories_train
  Learn... number_of_iterations_train 1e-7 Minimum-squared-error

  call get_fractioncorrect ffnet pattern_train categories_train
  fractionCorrect_post = fractionCorrect
  call get_costs ffnet pattern_train categories_train
  costs_post = costs
 
  for j to nspeakers_test

    select ffnet    
    select speakerindex
    index = speaker_test1 - 1 + j
    speakerlabel$ = Get row label... j
    from = Get value... j 1
    to = Get value... j 2
    select table_total
    To Pattern and Categories... 'from' 'to' 0 0
    pattern_test = selected ("Pattern")
    categories_test = selected ("Categories")
      
    if i = 1
      select result
      Set row label (index)... j 'speakerlabel$'
      Set value... j 1 from
      Set value... j 2 to
      Set value... j 3 index
      Set value... j 4 number_of_iterations_train
      Set value... j 5 number_of_iterations_test
    endif
	
	global_column = static_columns + (i - 1) * 3 * 4 + 1

    select result
    Set value... j global_column costs_pre
    global_column += 1
    Set value... j global_column fractionCorrect_pre
    global_column += 1 
    Set value... j global_column costs_post
    global_column += 1
    Set value... j global_column fractionCorrect_post
    global_column += 1 
    
    for layer to 2
      call save_results ffnet pattern_test categories_test result j
      select ffnet
      Copy... ffnet_copy
      ffnet_copy = selected ("FFNet")
      Select biases... layer
      Reset... 0.1
      plus pattern_test
      plus categories_test
      Learn... number_of_iterations_test 1e-7 Minimum-squared-error
      call save_results ffnet pattern_test categories_test result j
      select ffnet_copy
      Remove
    endfor
    
    select pattern_test
    plus categories_test
    Remove

  endfor

  select ffnet
  Remove
endfor

speakerstring$ = "'speaker_train1'"+"_'speaker_train2'"+"_'speaker_test1'"+
  ... "_'speaker_test2'"
select result

# fix the speakername (remove underscore at label start)
Change row labels... ^_ "" 0 Regular Expressions

# reorder the columns Eb-1,Eb-2,...Eb-10, Cb-1,..Cb-10, etc.
procedure copy_reordered table_id
  select table_id
  columns$ = "1 2 3 4 5"
  for j from 6 to 17
    for i to 10
      c = j + (i - 1) * 12
      columns$ = columns$ + " 'c'"
    endfor
  endfor
  Extract column ranges... 'columns$'
endproc

call copy_reordered result

Write to short text file... 'savedir$'biasadaption_results_'speakerstring$'_'date$'.TableOfReal



